DocusignSdk class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
platformVersion
→ Future<
String> -
no setter
Static Methods
-
addObserver(
String event, dynamic callback(Map)) → void -
cachedEnvelopeIds(
) → Future -
cacheTemplateWithId(
String templateId) → Future -
init(
) → dynamic -
loginWithEmail(
{String? password, String? email, String? integratorKey, String? host}) → Future -
removeCachedEnvelopes(
) → Future -
removeCachedEnvelopeWithId(
dynamic envelopeId) → Future -
removeCachedTemplateWithId(
String templateId) → Future -
removeObserver(
String event) → void -
renderWithTemplateId(
String templateId, {DocuSignSigningMode signingMode = DocuSignSigningMode.online, bool animated = true, EnvelopeDefaults? envelopeDefaults}) → Future -
starListenEnvelopNotification(
) → Future -
syncEnvelopes(
) → Future